==> jc-1.4.0.tar.gz: javax/swing/plaf/FontUIResource.h <==
// public class javax.swing.plaf.FontUIResource

// class file dependencies
// @dep_class e9e8e2618ea2bad5 java_awt_Font
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class aa7776373e455ce0 javax_swing_plaf_FontUIResource

// header file dependencies
// @dep_header java_awt_Font

#include "java/awt/Font.h"

#ifndef _JC_javax_swing_plaf_FontUIResource_H_
#define _JC_javax_swing_plaf_FontUIResource_H_

// Forward structure declarations
struct _jc_java_awt_Font$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_FontUIResource$sub_refs	_jc_javax_swing_plaf_FontUIResource$sub_refs;
typedef struct _jc_javax_swing_plaf_FontUIResource$sub_nonrefs	_jc_javax_swing_plaf_FontUIResource$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_FontUIResource$refs	_jc_javax_swing_plaf_FontUIResource$refs;
typedef struct _jc_javax_swing_plaf_FontUIResource$nonrefs	_jc_javax_swing_plaf_FontUIResource$nonrefs;
typedef struct _jc_javax_swing_plaf_FontUIResource$object	_jc_javax_swing_plaf_FontUIResource$object;

typedef const struct _jc_javax_swing_plaf_FontUIResource$vmethods	_jc_javax_swing_plaf_FontUIResource$vmethods;
typedef const struct _jc_javax_swing_plaf_FontUIResource$vtable	_jc_javax_swing_plaf_FontUIResource$vtable;
typedef const struct _jc_javax_swing_plaf_FontUIResource$vtype	_jc_javax_swing_plaf_FontUIResource$vtype;

// Constructors
extern void _jc_javax_swing_plaf_FontUIResource$method$_init$b709f73b4bc63e20(_jc_env *, struct _jc_javax_swing_plaf_FontUIResource$object *, struct _jc_java_awt_Font$object *);
extern void _jc_javax_swing_plaf_FontUIResource$method$_init$c8ef0122855cf0c5(_jc_env *, struct _jc_javax_swing_plaf_FontUIResource$object *, struct _jc_java_lang_String$object *, jint, jint);

// Virtual methods structure
struct _jc_javax_swing_plaf_FontUIResource$vmethods {
};

// Vtable
struct _jc_javax_swing_plaf_FontUIResource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Font$vmethods	java_awt_Font;
	_jc_javax_swing_plaf_FontUIResource$vmethods	javax_swing_plaf_FontUIResource;
};

// Vtype
struct _jc_javax_swing_plaf_FontUIResource$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_FontUIResource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_FontUIResource$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_FontUIResource$refs {
    _jc_javax_swing_plaf_FontUIResource$sub_refs	javax_swing_plaf_FontUIResource;
    _jc_java_awt_Font$sub_refs	java_awt_Font;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_FontUIResource$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_FontUIResource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Font$sub_nonrefs	java_awt_Font;
    _jc_javax_swing_plaf_FontUIResource$sub_nonrefs	javax_swing_plaf_FontUIResource;
};

// Object instance structure
struct _jc_javax_swing_plaf_FontUIResource$object {
	_jc_javax_swing_plaf_FontUIResource$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_FontUIResource$vtype	*vtype;
	_jc_javax_swing_plaf_FontUIResource$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_FontUIResource$vtype _jc_javax_swing_plaf_FontUIResource$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_FontUIResource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_FontUIResource$class_object;

#endif	/* _JC_javax_swing_plaf_FontUIResource_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/FontUIResource.h <==
// public class javax.swing.plaf.FontUIResource

// class file dependencies
// @dep_class 2f6d2e18b0d0e897 java_awt_Font
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class aa7776373e455ce0 javax_swing_plaf_FontUIResource

// header file dependencies
// @dep_header java_awt_Font

#include "java/awt/Font.h"

#ifndef _JC_javax_swing_plaf_FontUIResource_H_
#define _JC_javax_swing_plaf_FontUIResource_H_

// Forward structure declarations
struct _jc_java_awt_Font$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_FontUIResource$sub_refs	_jc_javax_swing_plaf_FontUIResource$sub_refs;
typedef struct _jc_javax_swing_plaf_FontUIResource$sub_nonrefs	_jc_javax_swing_plaf_FontUIResource$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_FontUIResource$refs	_jc_javax_swing_plaf_FontUIResource$refs;
typedef struct _jc_javax_swing_plaf_FontUIResource$nonrefs	_jc_javax_swing_plaf_FontUIResource$nonrefs;
typedef struct _jc_javax_swing_plaf_FontUIResource$object	_jc_javax_swing_plaf_FontUIResource$object;

typedef const struct _jc_javax_swing_plaf_FontUIResource$vmethods	_jc_javax_swing_plaf_FontUIResource$vmethods;
typedef const struct _jc_javax_swing_plaf_FontUIResource$vtable	_jc_javax_swing_plaf_FontUIResource$vtable;
typedef const struct _jc_javax_swing_plaf_FontUIResource$vtype	_jc_javax_swing_plaf_FontUIResource$vtype;

// Constructors
extern void _jc_javax_swing_plaf_FontUIResource$method$_init$b709f73b4bc63e20(_jc_env *, struct _jc_javax_swing_plaf_FontUIResource$object *, struct _jc_java_awt_Font$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_FontUIResource$method$_init$c8ef0122855cf0c5(_jc_env *, struct _jc_javax_swing_plaf_FontUIResource$object *, struct _jc_java_lang_String$object *, jint, jint) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_plaf_FontUIResource$vmethods {
};

// Vtable
struct _jc_javax_swing_plaf_FontUIResource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Font$vmethods	java_awt_Font;
	_jc_javax_swing_plaf_FontUIResource$vmethods	javax_swing_plaf_FontUIResource;
};

// Vtype
struct _jc_javax_swing_plaf_FontUIResource$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_FontUIResource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_FontUIResource$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_FontUIResource$refs {
    _jc_javax_swing_plaf_FontUIResource$sub_refs	javax_swing_plaf_FontUIResource;
    _jc_java_awt_Font$sub_refs	java_awt_Font;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_FontUIResource$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_FontUIResource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Font$sub_nonrefs	java_awt_Font;
    _jc_javax_swing_plaf_FontUIResource$sub_nonrefs	javax_swing_plaf_FontUIResource;
};

// Object instance structure
struct _jc_javax_swing_plaf_FontUIResource$object {
	_jc_javax_swing_plaf_FontUIResource$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_FontUIResource$vtype	*vtype;
	_jc_javax_swing_plaf_FontUIResource$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_FontUIResource$vtype _jc_javax_swing_plaf_FontUIResource$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_FontUIResource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_FontUIResource$class_object;

#endif	/* _JC_javax_swing_plaf_FontUIResource_H_ */
